Documentation
¶
Overview ¶
Package bumpupdated implements a launchr plugin with bumper functionality
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type BumpAction ¶
BumpAction is a launchr.Service providing bumper functionality.
type BumperRepo ¶
type BumperRepo struct {
// contains filtered or unexported fields
}
BumperRepo encapsulates Git-related operations for bumping versions in a Git repository.
func (*BumperRepo) Commit ¶
func (r *BumperRepo) Commit() error
Commit stores the current changes to the Git repository with the default commit message and author.
func (*BumperRepo) GetLastCommitShortHash ¶
func (r *BumperRepo) GetLastCommitShortHash() (string, error)
GetLastCommitShortHash gets the short hash of the latest commit in the Git repository.
func (*BumperRepo) IsOwnCommit ¶
func (r *BumperRepo) IsOwnCommit() bool
IsOwnCommit checks if the latest commit in the Git repository was made by the bumper.
type Plugin ¶
type Plugin struct {
// contains filtered or unexported fields
}
Plugin is launchr plugin providing bump action.
func (*Plugin) CobraAddCommands ¶
CobraAddCommands implements launchr.CobraPlugin interface to provide bump functionality.
func (*Plugin) PluginInfo ¶
func (p *Plugin) PluginInfo() launchr.PluginInfo
PluginInfo implements launchr.Plugin interface.
type Resource ¶
type Resource struct {
// contains filtered or unexported fields
}
Resource represents a ansible resource
func (*Resource) GetVersion ¶
GetVersion retrieves the version of the resource from the plasma.yaml
func (*Resource) UpdateVersion ¶
UpdateVersion updates the version of the resource in the plasma.yaml file