bumpupdated

package module
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2023 License: Apache-2.0 Imports: 12 Imported by: 0

README

bump-updated

Update the version of resources that were updated in last commit

List of excluded files
  • README.md
  • README.svg

Documentation

Overview

Package bumpupdated implements a launchr plugin with bumper functionality

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func PromptError

func PromptError(err error)

PromptError prints an error.

Types

type BumpAction

type BumpAction interface {
	launchr.Service
	Bump() error
}

BumpAction is a launchr.Service providing bumper functionality.

type BumperRepo

type BumperRepo struct {
	// contains filtered or unexported fields
}

BumperRepo encapsulates Git-related operations for bumping versions in a Git repository.

func (*BumperRepo) Commit

func (r *BumperRepo) Commit() error

Commit stores the current changes to the Git repository with the default commit message and author.

func (*BumperRepo) GetLastCommitShortHash

func (r *BumperRepo) GetLastCommitShortHash() (string, error)

GetLastCommitShortHash gets the short hash of the latest commit in the Git repository.

func (*BumperRepo) IsOwnCommit

func (r *BumperRepo) IsOwnCommit() bool

IsOwnCommit checks if the latest commit in the Git repository was made by the bumper.

type Plugin

type Plugin struct {
	// contains filtered or unexported fields
}

Plugin is launchr plugin providing bump action.

func (*Plugin) CobraAddCommands

func (p *Plugin) CobraAddCommands(rootCmd *cobra.Command) error

CobraAddCommands implements launchr.CobraPlugin interface to provide bump functionality.

func (*Plugin) OnAppInit

func (p *Plugin) OnAppInit(app launchr.App) error

OnAppInit implements launchr.Plugin interface.

func (*Plugin) PluginInfo

func (p *Plugin) PluginInfo() launchr.PluginInfo

PluginInfo implements launchr.Plugin interface.

type Resource

type Resource struct {
	// contains filtered or unexported fields
}

Resource represents a ansible resource

func (*Resource) GetName

func (r *Resource) GetName() string

GetName returns a resource name

func (*Resource) GetVersion

func (r *Resource) GetVersion() (string, error)

GetVersion retrieves the version of the resource from the plasma.yaml

func (*Resource) UpdateVersion

func (r *Resource) UpdateVersion(version string) bool

UpdateVersion updates the version of the resource in the plasma.yaml file

Directories

Path Synopsis
cmd
launchr command
Package executes Launchr application.
Package executes Launchr application.

Jump to